@@ -6,6 +6,7 @@ from rest_framework.reverse import reverse
 
 from django_comments_xtd import get_model as get_comment_model
 from django_comments_xtd.conf import settings
+from django_comments_xtd.models import max_thread_level_for_content_type
 from django_comments_xtd.utils import (
     get_current_site_id, get_app_model_options, get_html_id_suffix
 )
@@ -97,7 +98,8 @@ def commentbox_props(obj, user, request=None):
             "timestamp": form['timestamp'].value(),
             "security_hash": form['security_hash'].value()
         },
-        "html_id_suffix": get_html_id_suffix(obj)
+        "html_id_suffix": get_html_id_suffix(obj),
+        "max_thread_level": max_thread_level_for_content_type(ctype),
     }
     try:
         user_is_authenticated = user.is_authenticated()
