@@ -1,7 +1,7 @@
 from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.shortcuts import get_current_site
-from django.utils import formats
+from django.utils import formats, timezone
 from django.utils.html import escape
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext as _, activate, get_language
@@ -12,10 +12,11 @@ from django_comments.models import CommentFlag
 from django_comments.signals import comment_will_be_posted, comment_was_posted
 from rest_framework import exceptions, serializers
 
-from django_comments_xtd import signed, views
+from django_comments_xtd import get_model, signed, views
 from django_comments_xtd.conf import settings
 from django_comments_xtd.models import (TmpXtdComment, XtdComment,
-                                        LIKEDIT_FLAG, DISLIKEDIT_FLAG)
+                                        LIKEDIT_FLAG, DISLIKEDIT_FLAG,
+                                        max_thread_level_for_content_type)
 from django_comments_xtd.signals import (should_request_be_authorized,
                                          confirmation_received)
 from django_comments_xtd.utils import get_app_model_options
@@ -64,6 +65,20 @@ class WriteCommentSerializer(serializers.Serializer):
                 return self.request.user.email
         return value
 
+    def validate_reply_to(self, value):
+        if value != 0:
+            try:
+                parent = get_model().objects.get(pk=value)
+            except get_model().DoesNotExist:
+                raise serializers.ValidationError(
+                    "reply_to comment does not exist")
+            else:
+                max = max_thread_level_for_content_type(parent.content_type)
+                if parent.level == max:
+                    raise serializers.ValidationError(
+                        "Max thread level reached")
+        return value
+
     def validate(self, data):
         ctype = data.get("content_type")
         object_pk = data.get("object_pk")
@@ -124,7 +139,8 @@ class WriteCommentSerializer(serializers.Serializer):
         #  * Comment created (http 201),
         #  * Confirmation sent by mail (http 204),
         #  * Comment in moderation (http 202),
-        #  * Comment rejected (http 403).
+        #  * Comment rejected (http 403),
+        #  * Comment have bad data (http 400).
         site = get_current_site(self.request)
         resp = {
             'code': -1,
@@ -247,7 +263,11 @@ class ReadCommentSerializer(serializers.ModelSerializer):
 
     def get_submit_date(self, obj):
         activate(get_language())
-        return formats.date_format(obj.submit_date, 'DATETIME_FORMAT',
+        if settings.USE_TZ:
+            submit_date = timezone.localtime(obj.submit_date)
+        else:
+            submit_date = obj.submit_date
+        return formats.date_format(submit_date, 'DATETIME_FORMAT',
                                    use_l10n=True)
 
     def get_comment(self, obj):
