@@ -34,6 +34,9 @@ class CommentCreate(generics.CreateAPIView):
                 response_msg = [k for k in six.iterkeys(serializer.errors)]
             return Response(response_msg, status=400)
         if self.resp_dict['code'] == 201:  # The comment has been created.
+            response.data.update({
+                'id': self.resp_dict['comment']['xtd_comment'].id
+            })
             return response
         elif self.resp_dict['code'] in [202, 204, 403]:
             return Response({}, status=self.resp_dict['code'])
